Bridges WebAuthn JSON between the server and a platform passkey plugin.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
authenticate(
Map< String, dynamic> options) → Future<Map< String, dynamic> > -
optionsis PublicKeyCredentialRequestOptionsJSON; return AuthenticationResponseJSON. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
register(
Map< String, dynamic> options) → Future<Map< String, dynamic> > -
optionsis PublicKeyCredentialCreationOptionsJSON; return RegistrationResponseJSON. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited